pro bitpad,x_ret,y_ret,npnts_ret,nlines_ret
;
;+
; NAME: BITPAD
; PURPOSE:
;   To read data inputted from the bitpad, plot it, and write out the values
;   to a file and/or a hardcopy
; CATEGORY:
;   Bitpad, data entry
; CALLING SEQUENCE:
;    BITPAD   [,X [,Y [,NPNTS [,NLINES]]]]
; INPUTS:
;    none
; OPTIONAL INPUT PARAMETERS:
;    none
; KEYWORD PARAMETERS:
;    none
; OUTPUTS:
;    none
; OPTIONAL OUTPUT PARAMETERS:
;    X - returns the arrays of X coordinates of dimension (nlines,npnts(nlines))
;    Y - returns the arrays of Y coordinates of dimension (nlines,npnts(nlines))
;        The X parameter must included before Y
;    NPNTS - returns the array of point counts for each data line
;            Dimension (nlines). The X and Y parameters must be included
;            before NPNTS
;    NLINES - returns the number of data lines as a scalar
;             The X, Y and NPNTS parameters must be included before NLINES
; COMMON BLOCKS:
;       BPD_common,xtype,xmax,xmin,xscale,bp_x_offset,$
;                  ytype,ymax,ymin,yscale,bp_y_offset,rot_angle 
; SIDE EFFECTS:
; RESTRICTIONS:
;    The user must be logged onto the mainframe computer (OTT001).
;    The required IDL routines are;
;                     BITPAD.PRO
;                     BPD_AXIS.PRO
;                     BPD_EDIT.PRO
;                     BPD_CONTROL.PRO
;                     BPD_SAVE.PRO
;                     BITPAD_READ.PRO
;     as well as BITPAD_READ.EXE from BITPAD_READ.FOR
;     and BITPAD_SETUP.COM
; PROCEDURE:
;    At the DCL level enter  @BITPAD_SETUP.COM
;    This will allocate the bitpad terminal line.
;    Then start IDL and be sure the Utility IDL library is on the path
;    then enter BITPAD
; MODIFICATION HISTORY:
;    Created by J. D. Trickey  15-DEC-1992
;-
common BPD_common,xtype,xmax,xmin,xscale,bp_x_offset,$
                  ytype,ymax,ymin,yscale,bp_y_offset,rot_angle 
;
!quiet=1
;
set_plot,'tek'
device,/tek4014
;
choice=' '
fill=99999.9
saved=0
n_save=0
axis_done=0
lines=0
end_loop=0
while (end_loop eq 0) do begin
   print,' Bitpad Entry Menu ','A> enter new Axes (new plot)',$
         'D> enter Data line',$
         'E> Edit data Line',$
         'W> Write data line(s) to a file',$
         'H> make a Hardcopy (file)',$ 
         'Q> Quit',$
         '  Enter Choice ',$
         format='(7(1x,a,/),1x,a,$)'
   read,choice
   choice=strupcase(choice)
   case choice of
      'A': begin
              if (lines ge 1) and (saved eq 0) then begin
                 print,' Save previous data entered? (Y/N) [Y] ',format='(1x,a,$)'
                 test=' '
                 read,test,format='(a)'   
                 test=strupcase(test)
                 if (test ne 'N') then begin
                    bpd_save,x_save,y_save,lines,n_pnts,n_save
                    saved=1
                 endif
              endif
              bpd_axis
              axis_done=1
              n_save=0l
              lines=0
              saved=0
              n_pnts=[0l]
           end
      'D': begin
              if (axis_done eq 1) then begin
                  bpd_data,data_x,data_y
                  lines=lines+1                             
                  n_x=n_elements(data_x)
                  if (n_x gt n_save) then n_save=n_elements(data_x) 
                  if lines eq 1 then n_pnts=[n_x] else n_pnts=[n_pnts,n_x]
                  temp_x=fltarr(lines,n_save)
                  temp_y=fltarr(lines,n_save)
                  if (lines gt 1) then begin
                     for i=1,lines-1 do begin
                         temp_x(i-1,0:n_pnts(i-1)-1)=x_save(i-1,0:n_pnts(i-1)-1)
                         temp_y(i-1,0:n_pnts(i-1)-1)=y_save(i-1,0:n_pnts(i-1)-1)
                     endfor
                  endif
                  temp_x(lines-1,0:n_x-1)=data_x
                  temp_y(lines-1,0:n_x-1)=data_y
                  x_save=temp_x
                  y_save=temp_y
                  plot,x_save(0,0:n_pnts(0)-1),y_save(0,0:n_pnts(0)-1),$
                       psym=-3,max_value=fill-1.,xtype=xtype,ytype=ytype
                  if lines ge 2 then for i=2,lines do $
                    oplot,x_save(i-1,0:n_pnts(i-1)-1),$
                          y_save(i-1,0:n_pnts(i-1)-1),$
                          psym=-3,max_value=fill-1.
              endif else begin
                  print,'*** Axes not set ***'
              endelse
           end
      'E': begin
              print,' Enter Edit line? (1 to ',lines,format='(1x,a,i,'')'',$)'
              read,edt_line,format='(i)'
              if (edt_line ge 1) and (edt_line le lines) then begin
                  bpd_edit,x_save,y_save,lines,n_pnts,edt_line,n_save
                  saved=0
              endif else begin
                  print,'*** Invalid Line Number (line not entered) ***'
              endelse   
           end
      'W': begin
              if (lines ge 1) then begin
                 bpd_save,x_save,y_save,lines,n_pnts,n_save
                 saved=1
              endif else begin
                  print,'*** No Data Available ***'
              endelse
           end
      'H': begin
              if (lines ge 1) then begin
                 file=' '
                 print,' Enter PostScript file name ',format='(1x,a,$)'
                 read,file
                 open_ps,file,orient='l'
                 plot,x_save(0,0:n_pnts(0)-1),y_save(0,0:n_pnts(0)-1),$
                      psym=-3,max_value=fill-1.,xtype=xtype,ytype=ytype
                 if lines ge 2 then for i=2,lines do $
                    oplot,x_save(i-1,0:n_pnts(i-1)-1),$
                          y_save(i-1,0:n_pnts(i-1)-1),$
                          psym=-3,max_value=fill-1.
                 close_ps
              endif else begin
                  print,'*** No Data Available ***'
              endelse
           end
      'Q': begin
              if (lines ge 1) and (saved eq 0) then begin
                 print,' Save data entered? (Y/N) [Y] ',format='(1x,a,$)'
                 test=' '
                 read,test,format='(a)'   
                 test=strupcase(test)
                 if (test ne 'N') then begin
                    bpd_save,x_save,y_save,lines,n_pnts,n_save
                    saved=1
                 endif
              endif
              end_loop=1
           end
     else: print,'--- Invalid Choice ---'
   endcase
endwhile
;
case n_params() of
  0: return
  1: x_ret=x_save
  2: begin
        x_ret=x_save
        y_ret=y_save
     end
  3: begin
        x_ret=x_save
        y_ret=y_save
        npnts_ret=n_pnts
     end
  4: begin
        x_ret=x_save
        y_ret=y_save
        npnts_ret=n_pnts
        nlines_ret=lines
     end
  else: begin
        x_ret=x_save
        y_ret=y_save
        npnts_ret=n_pnts
        nlines_ret=lines
     end
endcase
;
return
end
