pro nrclogo,xpos,ypos,factor=fact,english=eng,french=frn,$
                      portrait=port,vertical=vert,flag=flag,$
                      canada=can,letter=let,herzberg=herz,$
                      color=color
;+
; NAME:  NRCLOGO
; PURPOSE:
;      to draw an NRC logo on IDL plots for identification purposes.
;      The default logo is bilingual.
;      A Canadian flag and the Canada logo are also available.
; CATEGORY:
;      plotting,logo
; CALLING SEQUENCE:
;      NRCLOGO,X_POS,Y_POS  [,FACTOR=number] [,/VERTICAL] [,/PORTRAIT]
;                           [,/ENGLISH] [,/FRENCH]
;                           [,/FLAG] [,/CANADA] 
;                           [,/LETTER] [,/HERZBERG]
; INPUTS:
;     X_POS - horizontal position of lower left corner in normal coordinates
;     Y_POS - vertical position of lower left corner in normal coordinates
; OPTIONAL INPUT PARAMETERS:
;     none
; KEYWORD PARAMETERS:
;     FACTOR - multiplication factor to control the size of the logo
;               Default = 0.1
;     VERTICAL - draws logo vertically
;     PORTRAIT - distorts logo so that it will look right when rotated
;                into portrait mode
;     ENGLISH - draws only the english portion of the logo
;     FRENCH - draws only the french portion of the logo
;     FLAG - draws Canadian flag
;     CANADA - draws Canada logo
;     LETTER - draws NRC letterhead (position is at top of page, factor
;               has no effect on size)
;     HERZBERG - adds 'Herzberg Institute' to letterhead (use with
;                LETTER keyword, has no effect otherwise)
;     COLOR - determines the color of the logo
; OUTPUTS:
;     none
; OPTIONAL OUTPUT PARAMETERS:
;     none
; COMMON BLOCKS:
;     none
; SIDE EFFECTS:
;     This program stores and reset the values of the system variables
;     it uses, but there may be side effects indirectly, so it is recommended
;     that this routine be used before or after the main plotting routines.
; RESTRICTIONS:
;     none
; PROCEDURE:
; MODIFICATION HISTORY:
;  Created by J. D. Trickey - 31-July-1991
;  added COLOR keyword - J. D. Trickey - 21-FEB-1992
;-
;
save_x=!x
save_y=!y
save_p=!p
;
if keyword_set(fact) then factor=fact else factor=0.1
if keyword_set(color) then !p.color=color
;
!x.style=1+4
!y.style=1+4
!p.title=''
!p.subtitle=''
!x.title=''
!y.title=''
;
!p.noerase=1
;
if keyword_set(port) then rfact=0.763916 else rfact=1.0
;
leaf_x=[6.7,6.9,4.0,4.5,1.7,$
        2.1,1.7,3.3,3.7,5.5,$
        4.9,5.9,7.0,8.1,9.1,$
        8.5,10.3,10.7,12.3,11.9,$
        12.3,9.5,10.0,7.1,7.3,$
        6.7]
leaf_y=[1.0,4.0,3.5,4.75,6.8,$
        7.0,9.1,8.9,9.6,8.2,$
        11.5,11.0,13.0,11.0,11.5,$
        8.2,9.6,8.9,9.1,7.0,$
        6.8,4.75,3.5,4.0,1.0,$
        1.0]
;
box_x=[0.0,0.0,7.0,7.0,0.0]
box_y=[0.0,14.5,14.5,0.0,0.0]
leaf_y=leaf_y*1.3
box_y=box_y*1.3
;
if keyword_set(flag) then begin
   set_viewport,xpos,xpos+0.2*factor,ypos,ypos+0.15*factor
   !x.range=[0.,20.]
   !y.range=[0.,15.]
   plot,[0.],[0.]
   if keyword_set(vert) then begin
      polyfill,box_y/rfact*(-1),box_x*rfact
      polyfill,leaf_y/rfact*(-1),(leaf_x+7.0)*rfact
      polyfill,box_y/rfact*(-1),(box_x+21.0)*rfact
   endif else begin
      polyfill,box_x/rfact,box_y*rfact
      polyfill,(leaf_x+7.0)/rfact,leaf_y*rfact
      polyfill,(box_x+21.0)/rfact,box_y*rfact
   endelse
;
endif else if keyword_set(let) then begin
;
   
;
   if !d.name eq 'PS' then begin
      device,/helvetica
      set_viewport,0.02,0.02+1.0*0.22,0.95,0.95+0.15*0.24
      !x.range=[0.,100.]
      !y.range=[0.,15.]
      plot,[0.],[0.]
      if keyword_set(vert) then begin
         polyfill,box_y/rfact*(-1),box_x*rfact
         polyfill,leaf_y/rfact*(-1),(leaf_x+7.0)*rfact
         polyfill,box_y/rfact*(-1),(box_x+21.0)*rfact
      endif else begin
         polyfill,box_x/rfact,box_y*rfact
         polyfill,(leaf_x+7.0)/rfact,leaf_y*rfact
         polyfill,(box_x+21.0)/rfact,box_y*rfact
      endelse
   ;
      xyouts,0.11,0.975,'National Research Council',size=0.8,/normal,font=0 
      xyouts,0.11,0.95,'Canada',size=0.8,/normal,font=0 
      xyouts,0.36,0.975,'Conseil National de Recherches',size=0.8,/normal,font=0 
      xyouts,0.36,0.95,'Canada',size=0.8,/normal,font=0 
      if keyword_set(herz) then begin
         xyouts,0.11,0.9,'Herzberg Institute',size=0.8,/normal,font=0 
         xyouts,0.11,0.875,'of Astrophysics',size=0.8,/normal,font=0 
         xyouts,0.36,0.9,'Institut Herzberg',size=0.8,/normal,font=0 
         xyouts,0.36,0.875,'d''astrophysique',size=0.8,/normal,font=0
         xyouts,0.11,0.825,'Ottawa, Canada',size=0.65,/normal,font=0 
         xyouts,0.11,0.805,'K1A 0R6',size=0.65,/normal,font=0 
      endif
;
   endif else begin
      set_viewport,0.0,1.0*0.16,0.95,0.95+0.15*0.16
      !x.range=[0.,100.]
      !y.range=[0.,15.]
      plot,[0.],[0.]
      if keyword_set(vert) then begin
         polyfill,box_y/rfact*(-1),box_x*rfact
         polyfill,leaf_y/rfact*(-1),(leaf_x+7.0)*rfact
         polyfill,box_y/rfact*(-1),(box_x+21.0)*rfact
      endif else begin
         polyfill,box_x/rfact,box_y*rfact
         polyfill,(leaf_x+7.0)/rfact,leaf_y*rfact
         polyfill,(box_x+21.0)/rfact,box_y*rfact
      endelse
;
      xyouts,0.07,0.965,'National Research Council',size=0.6,/normal
      xyouts,0.07,0.95,'Canada',size=0.6,/normal
      xyouts,0.25,0.965,'Conseil National de Recherches',size=0.6,/normal
      xyouts,0.25,0.95,'Canada',size=0.6,/normal
      if keyword_set(herz) then begin
         xyouts,0.07,0.92,'Herzberg Institute',size=0.8,/normal,font=0 
         xyouts,0.07,0.905,'of Astrophysics',size=0.8,/normal,font=0 
         xyouts,0.25,0.92,'Institut Herzberg',size=0.8,/normal,font=0 
         xyouts,0.25,0.905,'d''astrophysique',size=0.8,/normal,font=0
         xyouts,0.07,0.875,'Ottawa, Canada',size=0.65,/normal,font=0 
         xyouts,0.07,0.865,'K1A 0R6',size=0.65,/normal,font=0 
      endif
   endelse
;
endif else if keyword_set(can) then begin
;
   if keyword_set(vert) then orient=90. else orient=0.0
;
   xyouts,xpos,ypos,'!17C',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
;
   if keyword_set(vert) then begin
      y1=ypos+wfac
      xyouts,xpos,y1,'!17a',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      y1=y1+wfac
      xyouts,xpos,y1,'!17n',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      y1=y1+wfac
      xyouts,xpos,y1,'!17a',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      y1=y1+wfac
      xyouts,xpos,y1,'!17d',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      y1=y1+wfac
      xyouts,xpos,y1,'!17a',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      set_viewport,xpos-0.021*(factor/2.),xpos-0.021*(factor/2.)+0.2*factor/30.,$
                ypos+0.14*(factor/2.),ypos+0.14*(factor/2.)+0.15*factor/25.
      !x.range=[0.,20.]
      !y.range=[0.,15.]
      plot,[0.],[0.]
      polyfill,box_y*(-1),box_x
      polyfill,leaf_y*(-1),leaf_x+7.0
      polyfill,box_y*(-1),box_x+21.0
   endif else begin
      x1=xpos+wfac-0.006
      xyouts,x1,ypos,'!17a',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      x1=x1+wfac-0.005
      xyouts,x1,ypos,'!17n',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      x1=x1+wfac-0.006
      xyouts,x1,ypos,'!17a',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      x1=x1+wfac-0.006
      xyouts,x1,ypos,'!17d',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      x1=x1+wfac-0.006
      xyouts,x1,ypos,'!17a',size=factor,orientation=orient,$
         /normal,font=-1,width=wfac
      set_viewport,xpos+0.119*(factor/2.),xpos+0.119*(factor/2.)+0.2*factor/30.,$
                ypos+0.029*(factor/2.),ypos+0.029*(factor/2.)+0.15*factor/30.
      !x.range=[0.,20.]
      !y.range=[0.,15.]
      plot,[0.],[0.]
      polyfill,box_x,box_y
      polyfill,leaf_x+7.0,leaf_y
      polyfill,box_x+21.0,box_y
   endelse
;
endif else begin
   set_viewport,xpos,xpos+0.5*factor,ypos,ypos+0.25*factor
   !x.range=[0.,50.]
   !y.range=[0.,25.]
   plot,[0.],[0.]
   nr_x=[0.,4.,11.,16.5,17.,$
         27.,29.5,30.5,31.,30.5,$
         29.5,28.,18.,19.,31.,$
         33.,35.,36.5,38.,39.,$
         39.,38.,$
         37.,35.5,34.,36.,37.,$
         36.,37.,30.,31.,30.,$
         29.,24.,22.,15.,9.5,$
         7.,0.]
   nr_y=[0.,22.,22.,10.,13.,$
         13.,13.5,14.2,15.,15.8,$
         16.5,17.,17.,22.,22.,$
         21.5,20.75,20.,19.,18.,$
         15.,13.,$
         12.,11.,10.,8.5,7.,$
         2.,0.,0.,5.,6.,$
         7.,7.,0.,0.,12.,$
         0.,0.]
   nr_y=nr_y*1.3
;
   c_x=[22.,15.,13.5,12.,10.,$
       7.5,7.,7.,8.,10.,$
       12.,13.,15.,16.,22.5,$
       22.5,21.5,20.,16.0,10.,$
       7.,5.5,3.,1.,0.,$
       0.,1.,2.,4.,7.,$
       12.,15.,17.5,19.5,22.]
   c_y=[9.,9.,6.5,5.,5.,$
       6.5,8.,11.,14.,17.,$
       18.,18.,17.,14.5,14.5,$
       17.,19.5,21.,23.,23.,$
       21.5,20.5,18.,14.,11.,$
       8.,5.,3.,1.,0.,$
       0.,1.,2.5,4.5,9.]
   c_y=c_y*1.3
;
   dash_x=[0.,0.5,4.5,4.,0.]
   dash_y=[9.5,12.5,12.5,9.5,9.5]
   dash_y=dash_y*1.3
;
;
   if keyword_set(vert) then begin
      if keyword_set(eng) then begin
         polyfill,nr_y/rfact*(-1),nr_x*rfact
         polyfill,(c_y-0.5)/rfact*(-1),(c_x+39.)*rfact
      endif else if keyword_set(frn) then begin
         polyfill,(c_y-0.5)/rfact*(-1),c_x*rfact
         polyfill,nr_y/rfact*(-1),(nr_x+23.)*rfact
         polyfill,(c_y-0.5)/rfact*(-1),(c_x+62.)*rfact
      endif else begin 
         polyfill,(nr_y)/rfact*(-1),nr_x*rfact
         polyfill,(c_y-0.5)/rfact*(-1),(c_x+39.)*rfact
         polyfill,dash_y/rfact*(-1),(dash_x+62.)*rfact
         polyfill,(c_y-0.5)/rfact*(-1),(c_x+68.)*rfact
         polyfill,nr_y/rfact*(-1),(nr_x+91.)*rfact
         polyfill,(c_y-0.5)/rfact*(-1),(c_x+130.)*rfact
      endelse
   endif else begin
      if keyword_set(eng) then begin
         polyfill,nr_x/rfact,nr_y*rfact
         polyfill,(c_x+39.)/rfact,(c_y-0.5)*rfact
      endif else if keyword_set(frn) then begin
         polyfill,c_x/rfact,(c_y-0.5)*rfact
         polyfill,(nr_x+23.)/rfact,nr_y*rfact
         polyfill,(c_x+62.)/rfact,(c_y-0.5)*rfact
      endif else begin 
         polyfill,nr_x/rfact,nr_y*rfact
         polyfill,(c_x+39.)/rfact,(c_y-0.5)*rfact
         polyfill,(dash_x+62.)/rfact,dash_y*rfact
         polyfill,(c_x+68.)/rfact,(c_y-0.5)*rfact
         polyfill,(nr_x+91.)/rfact,nr_y*rfact
         polyfill,(c_x+130.)/rfact,(c_y-0.5)*rfact
      endelse
   endelse
;
endelse
;
!x=save_x
!y=save_y
!p=save_p
;
return
end
