pro OPEN_PS,file_name,$
    file=k_name,orientation=k_orient,extend=k_ex,Font=k_fnt,color=clr
;
;+
; NAME:  OPEN_PS
;
; PURPOSE:
;    Opens a file for PostScript graphics output. The user has the option
;    of changing the orientation and font used by the PostScript printer.
;    The user may enter the parameter and/or keywords on the command line,
;    or be prompted for the information.
;    If the graphics is in color the user should load the color table after
;    the file has been opened.
; CATEGORY:
;    Utility
; CALLING SEQUENCE:
;    OPEN_PS  [,file_name] 
;             [,/COLOR]
;             [,ORIENTATION=or_string] [,/EXTEND]
;             [,FONT=font_string]
; INPUTS:
;    No required inputs (see optional inputs)
; OPTIONAL INPUT PARAMETERS:
;    File_Name - name of the PostScript file to be opened
;                If this parameter is provided, the default values
;                for Font and Orientation will be used, unless specified
;                using the keyword(s) below.
;                If this parameter is not provided, the user will be prompted
;                for the file name as well as the Font and Orientation
;                (unless specified by keyword)
;                The keyword FILE=file_name may be used.
; KEYWORD PARAMETERS:
;    FILE=file_name        - Performs the task of the optional input 
;                            parameter File_Name, as above.
;    COLOR                 - Indicates that the graphics will be in color
;                            so the Postscript color setting should be
;                            activated.
;                            Be sure and load the color table after the
;                            file is opened 
;    ORIENTATION=or_string - String specifing landscape or portrait
;                            orientation of plot
;                                or_string='L'  - Landscape
;                                         ='P'  - Portrait
;    EXTEND                - Indicates that a Portrait plot should be 
;                            extended to fill the whole page
;    FONT=fo_string        - String containing the Font keywords for a
;                            PostScript device command.
;                               ex; fo_string='/times,/bold'
;                            See the IDL manual to obtain more information
;                            on PostScript fonts.
;                            This can also be used to include any other
;                            desired keywords for the IDL Device command
;
; OUTPUTS:
;    No output parameters
; OPTIONAL OUTPUT PARAMETERS:
;    No output parameters
; COMMON BLOCKS:
;    common PS_FILE_INFO,ps_file,Old_device,Old_setup
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; PROCEDURE:
;     The PostScript file is opened using OPEN_PS2 and closed using CLOSE_PS2
;
; MODIFICATION HISTORY:
;     27-April-1992 - Edited By J D Trickey - added /COLOR keyword 
;     10-April-1992 - Created By J D Trickey baised on previous versions 
;-
;
common PS_FILE_INFO,ps_file,Old_device,Old_setup
;
if !d.name eq 'PS' then begin
   print,'*** Postscript file ',ps_file,' is already open ***'
   cont='N'
   read, '    Do you wish to close it and continue (Y/N) [N] :',cont
   if (cont eq 'Y') or (cont eq 'y') then begin
      device,/close
   endif else begin
      return
   endelse
endif else begin
   Old_device=!d
   Old_setup=!p
endelse
;
if keyword_set(k_name) then file_name=k_name
prompt=0
if n_elements(file_name) eq 0 then begin
   prompt=1
   file_name=''
   read,'Postscript file name [PLOT.PS]:',file_name
   if file_name eq '' then file_name='PLOT.PS'
endif
;
cfont='N'
if keyword_set(k_fnt) then begin
   nfont=k_fnt
   cfont='Y'
endif else begin
   if prompt eq 1 then begin
      read,'Change font (or add any "device" keywords)? (y/[n]) :',cfont
      cfont=strupcase(cfont)
      nfont=''
      if cfont eq 'Y' then begin
PROMPT_AGAIN:
         print,' '
         read,'Enter font name or other keywords (e.g. /times,/bold) (? for help) :',nfont
         if nfont eq '?' then begin
            openr,inunit,'dan$:[trickey.graphics]ps.info',/get_lun
            line='' & readf,inunit,line
            count=0
            cont=' '
            while not eof(inunit) and (cont ne 'Q') do begin
               print,line
               count=count+1
               if count gt 20 then begin
                  print,' '
                  cont=''
                  read,'    Hit <CR> to continue, Q to quit help ...',cont
                  cont=strupcase(cont)
                  count=0
                  if (Old_device.name eq 'REGIS') then erase
               endif
               readf,inunit,line
            endwhile
            free_lun,inunit
            goto, prompt_again
         endif
         nfont=nfont
      endif
   endif
endelse   
;
orient='P'
if keyword_set(k_ex) then exppage='Y' else exppage='N'
if keyword_set(k_orient) then begin
   orient=k_orient
   orient=strupcase(orient)
endif else begin
   if prompt eq 1 then begin
      orient=''
      read,'Landscape or Portrait? (L/[P]) :',orient
      orient=strupcase(orient)
      if (orient ne 'L') and (orient ne 'P') then orient='P'
      if orient eq 'P' then begin
         if keyword_set(k_ex) then exppage='Y' else begin
            read,'Expand Portrait to fill printer page? ([Y]/N) :',exppage
            exppage=strupcase(exppage)
            if exppage ne 'N' then exppage='Y'
         endelse
      endif
   endif
endelse
;
color='N'
if prompt eq 1 then begin
   read,'Color? (Y/[N]) :',color
   color=strupcase(color)
   if color ne 'Y' then color='N'
   if color eq 'Y' then print,' --- Remember to load the color table --- '
endif
;
file_name=strupcase(file_name)
ps_file=file_name
set_plot,'ps'
device,file=file_name
;
print,' Postscript file ',file_name,' opened.'
; 
if keyword_set(clr) or (color eq 'Y') then begin
   device,/color
endif
;
if (orient eq 'L') then begin
   device,/landscape
endif else begin
   if exppage eq 'Y' then begin
      if keyword_set(clr) or (color eq 'Y') then begin
         device,/port,xsize=7.,ysize=9.,xoffset=0.75,yoffset=1.0,/inches
      endif else begin
         device,/port,xsize=7.,ysize=10.,xoffset=0.75,yoffset=0.5,/inches
      endelse
   endif else begin
      device,/port
   endelse
endelse
;
if cfont eq 'Y' then begin
   if strtrim(nfont,2) ne '' then begin
      !p.font=0
      dev_string='device,'+nfont
      istat=execute(dev_string)
   endif
endif
;
;
;
return
end
