PRO XT_CTABLE, ITAB, NAME, R, G, B
;+
;  NAME:
;     XT_CTABLE 
;  PURPOSE:
;     Extract a colour table from the file defined by the logical 
;        IDL_COLOUR_TABLE.
;  CATEGORY:
;     Z4 - IMAGE PROCESSING, COLOR TABLE MANIPULATION
;  CALLING SEQUENCE:
;     XT_CTABLE, ITAB, NAME, R,G,B
;  INPUTS:
;     ITAB = table number, from 0 to 15.
;        Table may be loaded using LD_CTABLE or LOADCT.
;     NAME = Name of color table, string up to 32 characters long.
;        R = red color gun vector, 256 elements.
;        G = green vector
;        B = blue vector
;     Note: To get the full 256 byte tables, you must disable the TVLCT 
;     command because it set the table length to 246/247.
;  OUTPUTS:
;     none.
;  COMMON BLOCKS:
;     none.
;  SIDE EFFECTS:
;     File IDL_COLOUR_TABLE is modified with new table.
;  PROCEDURE:
;     Straightforward.
;  MODIFICATION HISTORY:
;     Aug, 1982, DMS, Written.
;     Unix version, 1987, DMS.
;     MPA version,  F.Creutzberg,  4-JUL-1991
;-
;
  on_error,2                           ; return to caller if an error occurs
  if (itab lt 0) or (itab gt 15) then message,'Color table number out of range.'

  get_lun,iunit                        ;get a logical unit
  openu ,iunit,'IDL_COLOUR_TABLE',/block     ;open file

  aa=assoc(iunit,bytarr(32,16))        ; Access name record.
  a = aa(0)
  name = string(a(0:31,itab))          ; Fetch name 

  aa=assoc(iunit,bytarr(512))          ; Access vectors.
  a = aa(itab*2+1)                     ; Fetch red 
  r = a(0:255)                         ; Fetch red 
  g = a(256:511)                       ; Fetch green
  a = aa(itab*2+2)                     ; blue in 2nd block
  b = a(0:255)                         ; blue in 2nd block
  free_lun,iunit
  return
  end
