;+
; NAME:
;	GCED
; PURPOSE:
;	Convert geocentric coordinates to EDFL, near the Earth's surface..
; CALLING SEQUENCE:
;	gced, gclat, gclon, gcrkm, edlat, edlon, alt
; INPUTS:
;	GCLAT = Geocentric latitude in radians.
;	GCLON = Geocentric longitude in radians.
;	GCRKM = Geocentric distance in km.
;	All inputs are FLOAT, and should be either all scalars or all vectors.
; OUTPUTS:
;	EDLAT = EDFL latitude in radians.
;	EDLON = EDFL longitude in radians.
;	ALT   = Altitude (geodetic) above MSL in km.
;	All outputs are FLOAT, and are scalars or vectors according to input.
; PROCEDURE:
;	Calls CANECDIP, then GCGD to get ALT.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 25 Feb 1992: Written in IDL2.
;	IFG 27 Jul 1992: Added ON_ERROR.
;-

pro gced, gclat, gclon, gcrkm, edlat, edlon, alt

on_error, 2
if n_params() ne 6 then message, 'You must provide exactly 6 parameters'

flag = 0	; CANECDIP GC to EDFL
gclatf = array(gclat)
gclonf = array(gclon)
gcrkmf = array(gcrkm)
n = n_elements(gclatf)
edlat = fltarr(n)
edlon = fltarr(n)
erkm = fltarr(n)

canecdip, flag, gclatf, gclonf, gcrkmf, edlat, edlon, erkm
gcgd, gclatf, gcrkmf, gdlat, alt

if not isarray(gclat) then begin
   edlat = edlat(0)
   edlon = edlon(0)
   alt = alt(0)
   endif

return
end
