;+
; NAME:
;	LREGRESS
; PURPOSE:
;	Linear Regression.
; CALLING SEQUENCE:
;	LREGRESS, X, Y, A, B
; INPUTS:
;	X, Y = X and Y vectors.
; OUTPUTS:
;	A, B = Y intercept and slope: Y = A + B*X
; MODIFICATION HISTORY:
;	RES  7 Jan 1986.
;	IFG, 6 Feb 1991: No changes needed for IDL2.
;	IFG, 5 Jan 1993: Added ON_ERROR.
;-

	PRO LREGRESS, X, Y, A, B

	ON_ERROR, 2
	N = N_ELEMENTS(X)
	NY = N_ELEMENTS(Y)
	IF N NE NY THEN BEGIN
	  PRINT,'X and Y arrays must be same size.'
	  RETURN
	ENDIF

	XM = MEAN(X)
	YM = MEAN(Y)
	SX = TOTAL(X)
	SX2 = TOTAL(X*X)
	SY = TOTAL(Y)
	SXY = TOTAL(X*Y)

	B = (SXY - SX*SY/N)/(SX2 - SX*SX/N)
	A = YM - B*XM

	RETURN
	END
