;+
; NAME:
;	NICE_LEVELS
; PURPOSE:
;	Returns a vector suitable for use as contour levels.
;	Result has about six round values approximately covering but not
;	extending outside the range of the input.
; CALLING SEQUENCE:
;	Result = NICE_LEVELS( DATA, NLEVELS )
; INPUTS:
;	DATA = Numeric scalar or vector. Only MIN(A) and MAX(A) are used.
; OUTPUTS:
;	Result = A float vector of equally spaced values such that the first
;	is a little greater than MIN(A) and the last is a little less
;	than MAX(A), and the interval between values is of the form m*10^n,
;	where m=1,2, or 5.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRC, 19 Apr 1991, IDL2.
;	GRANT, 20 Sep 1993: Added NLEVELS argument, and used it in second
;	argument to NICE_TICKS call.
;-

function nice_levels, data, nlevels

if not keyword_set(nlevels) then nlevels = 6
levels = nice_ticks(data, nlevels+2)		; Tick marks spanning data
return, levels(1:n_elements(levels)-2)		; Drop first and last ticks
end
