;+
; NAME:
;	REPLY_CHAR
; PURPOSE:
;	Issue prompt then read and check one-character response.
; CALLING SEQUENCE:
;	Result = REPLY_CHAR( PROMPT, VALID_REPLY_LIST [,DEFAULT] )
; INPUTS:
;	PROMPT = Scalar string. Prompt to be output to terminal.
;	VALID_REPLY_LIST = Scalar string of valid response characters.
;	   Converted to uppercase before use.
; OPTIONAL INPUT PARAMETERS:
;	DEFAULT = Scalar string. Default response character.
;	   Converted to uppercase before use. ' ' if not specified.
; OUTPUTS:
;	Result = Scalar string. Single uppercase character selected from 
;	   VALID_REPLY_LIST.
; PROCEDURE:
;	Examines first character of keyboard response, or DEFAULT if <RETURN>.
;	If character is not in VALID_REPLY_LIST, then input is requested again.
; Example:
;	In the following, REPLY_CHAR will not return until the first 
;	   character of the response is 'n', 'N', 'y', 'Y' or <RETURN>.
;	IF REPLY_CHAR('Double X ?', 'yn', 'n') EQ 'Y' THEN X = 2*X
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 1990, IDL1.
;	IFG, 29 April 1991: Runs under IDL2.
;	IFG, 23 Dec 1992: Added ON_ERROR.
;-

function reply_char, prompt,valid_reply_list,default

on_error, 2
reply = ''
request:
if n_params() eq 3 then $
   default_prompt = ' ['+default+']' $
else $
   default_prompt = ''
read,prompt+default_prompt+': ',reply
if (n_params() eq 3) and (reply eq '') then begin
   reply = strupcase(default)
endif else begin
   reply = strupcase(strmid(reply+' ',0,1)) ; Upcase of first char, or '' -> ' '
   pos = strpos(strupcase(valid_reply_list),reply)
   if pos eq -1 then goto,request
   endelse
return,reply
end
