;+
; NAME:
;	STRESS
; PURPOSE:
;	String edit by sub-string.
; CATEGORY:
;	String functions.
; CALLING SEQUENCE:
;	new = STRESS(old,cmd,n,oldss,newss,ned)
; INPUTS:
;	old = string to edit.
;          cmd = edit command:
;              'P' = precede.
;              'F' = follow.
;              'D' = delete.
;              'R' = replace.
;       n = occurence number to process (0 = all).
;       oldss = reference substring.
;              oldss may have any of the following forms:
;              1. s	  a single substring.
;              2. s...    start at substring s, end at end of string.
;              3. ...e    from start of string to substring e.
;              4. s...e   from subs s to subs e.
;              5. ...     entire string.
;       newss = substring to add. Not needed for 'D'
;	ned = number of occurances actually changed.
; OPTIONAL INPUT PARAMETERS:
;	newss.
; OUTPUTS:
;	Function result is edited string.
; PROCEDURE:
;	Uses STREP and STRSUB.
; MODIFICATION HISTORY:
;	Written by R. Sterner, 6 Jan, 1985.
;	         RES --- 23 May, 1988 fixed a bug in SSTYP = 2.
;	         Johns Hopkins University Applied Physics Laboratory.
;           (FROM AN IDL1 USER LIBRARY)
;	Ian Grant, UWO, 21 Jan 1993: No changes needed for IDL2.
;	   Added ON_ERROR.
;-

FUNCTION STRESS,STRNG,CMDX,N,OLD,NEW,NED

	ON_ERROR, 2
	CMD = STRUPCASE(CMDX)
	PDOT = STRPOS(OLD,'...')
	SSL = STRLEN(OLD)
	SSTYP = 0
	POS1 = -1
	POS2 = -1
	RSTR = STRNG
	IF (PDOT EQ -1) THEN SSTYP = 1
;	IF ((PDOT>0) EQ SSL-3) THEN SSTYP = 2
	IF (PDOT GT 0) AND (PDOT EQ SSL-3) THEN SSTYP = 2
	IF (PDOT EQ 0) AND (SSL GT 3) THEN SSTYP = 3
	IF (PDOT GT 0) AND (PDOT LT SSL-3) THEN SSTYP = 4
	IF (PDOT EQ 0) AND (SSL EQ 3) THEN SSTYP = 5
	NED = 0		; number of occurances actually changed.


	CASE SSTYP OF
1:	  BEGIN
	    S = OLD
	    E = ''
	  END
2:	  BEGIN
	    S = STRSUB(OLD,0,SSL-4)
	    E = ''
    	  END
3:  	  BEGIN
	    S = ''
	    E = STRSUB(OLD,3,SSL-1)
	  END
4:  	  BEGIN
	    S = STRSUB(OLD,0,PDOT-1)
	    E = STRSUB(OLD,PDOT+3,SSL-1)
	  END
5:  	  BEGIN
	    S = ''
	    E = ''
	  END
ELSE: 	  PRINT, 'ERROR IN SSTYP'
	ENDCASE


;---------------  Find substring # N start  ---------------
	POS = -1
LOOP:
	FOR I = 0, N DO BEGIN
	  POS = POS + 1
	  CASE SSTYP OF
    1:      POS = STRPOS(RSTR,S,POS)
    2:      POS = STRPOS(RSTR,S,POS)
    4:      POS = STRPOS(RSTR,S,POS)
    3:      POS = STRPOS(RSTR,E,POS)
    5:      POS = 0
	  ENDCASE
  	  IF POS LT 0 THEN GOTO, DONE
	ENDFOR

;----------  Find substring # N END  ----------------
    	CASE SSTYP OF
1:  	  BEGIN
	    POS1 = POS
	    POS2 = POS + STRLEN(S) - 1
	  END
2:  	  BEGIN
	    POS1 = POS
	    POS2 = STRLEN(RSTR) - 1
	  END
3:  	  BEGIN
	    POS1 = 0
	    POS2 = POS + STRLEN(E) - 1
	  END
4:  	  BEGIN
	    POS1 = POS
	    POS2 = STRPOS(RSTR,E,POS+1)
	    IF (POS2 LT 0) THEN GOTO, DONE
	    POS2 = POS2 + STRLEN(E) - 1
	  END
5:  	  BEGIN
	    POS1 = 0
	    POS2 = STRLEN(RSTR) - 1
	  END
	ENDCASE

;------------  edit string  --------------
    	CASE CMD OF
'P':  	  BEGIN
	    RSTR = STREP(RSTR,CMD,POS1,NEW)
	    POS = POS + STRLEN(NEW)
	  END
'F':  	  BEGIN
	    RSTR = STREP(RSTR,CMD,POS2,NEW)
	    POS = POS + STRLEN(NEW)
	  END
'R':  	  BEGIN
	    RSTR = STREP(RSTR,'D',POS1,POS2-POS1+1)
	    IF (POS1 GT 0) THEN $
	      RSTR = STREP(RSTR,'F',POS1-1,NEW)
	    IF (POS1 EQ 0) THEN $
	      RSTR = STREP(RSTR,'P',0,NEW)
	    POS = POS + STRLEN(NEW) - 1
	  END
'D':  	  BEGIN
	    RSTR = STREP(RSTR,CMD,POS1,POS2-POS1+1)
	    POS = POS - 1
	  END
ELSE: 	  BEGIN
	    PRINT, 'Error in cmd'
	    RETURN,RSTR
	  END
ENDCASE

	NED = NED + 1
	IF SSTYP EQ 5 THEN RETURN,RSTR
	IF N EQ 0 THEN GOTO, LOOP

DONE:
	RETURN, RSTR
	END
