;+
; NAME:
;	STRCANTIME
; PURPOSE:
;	Returns string 'dd-mmm-yyyy hh:mm:ss' from CANOPUS time.
; CALLING SEQUENCE:
;	Result = STRCANTIME(CAN_TIME)
; INPUTS:
;	CAN_TIME = Scalar CANOPUS time.
; KEYWORD PARAMETERS:
;	DATE: If present and non-zero, the date will be included in Result.
;	TIME: If present and non-zero, the time will be included in Result.
;	If both or neither DATE and TIME is set then both dates and times will 
;	   be included in Result.
;	NOSECONDS: If present and non-zero, times do not include seconds.
; OUTPUTS:
;	Result = String containing date and/or time corresponding to CAN_TIME
;	converted to an integer.
; PROCEDURE:
;	Calls CIVIL_TIME.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, April 1991, IDL2.
;	IFG, 8 Nov 1991: Renamed from CANTIME2YMDTSTR to STRCANTIME.
;       IFG 27 Jul 1992: Added ON_ERROR.
;	IFG, 22 Dec 1992: Replaced YMD2STR and HMS2STR with inline code.
;	GRANT, 20 Sep 1993: Added keywords DATE, TIME, NOSECONDS.
;-

function strcantime, can_time, date=date, time=time, noseconds=nosec

on_error, 2

civil_time,y,mth,date_of_month,day,h,m,s,can_time

kd = keyword_set(date)
kt = keyword_set(time)
if kd and (not kt) then $
   datetime = 'D' $		; Date only
else if (not kd) and kt then $
   datetime = 'T' $		; Time only
else $
   datetime = 'B'		; Both

date_str = string(date_of_month, $
   strmid( 'JanFebMarAprMayJunJulAugSepOctNovDec', 3*(mth-1), 3), $
   y, $
   format="(i2,'-',a3,'-',i4)")

if keyword_set(nosec) then $
   time_str = string(h,m, format="(i2.2,':',i2.2)") $
else $
   time_str = string(h,m,s, format="(i2.2,':',i2.2,':',i2.2)")

case datetime of
   'D': return, date_str
   'T': return, time_str
   'B': return, date_str + ' ' + time_str
   endcase

end
