;+
; NAME:
;	VECT3_ANGLE
; PURPOSE:
;	Returns angle between two 3-component vectors.
; CALLING SEQUENCE:
;	Result = VECT3_ANGLE(V1,V2)
; INPUTS:
;	V1, V2 = 3-element FLOAT vectors.
; OUTPUTS:
;	Result = floating scalar. Angle between V1 and V2 in radians.
; RESTRICTIONS:
;	Vectors must have 3 elements.
; PROCEDURE:
;	angle = arcos( (v1.v2) / |v1||v2| )
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, Aug 1990: Written.
;	IFG, 6 May 1991: IDL1? Looks like this will run under IDL2.
;-

function vect3_angle,v1,v2

on_error,2                      ;Return to caller if an error occurs
return, acos( total(v1*v2) / sqrt(total(v1*v1) * total(v2*v2)))
end
